@@ -1,4 +1,4 @@
-# Copyrights 2007-2024 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.03.
@@ -6,9 +6,9 @@
 # OODoc into POD and HTML manual-pages.  See README.md
 # Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
-package Dancer2::Plugin::LogReport;
-use vars '$VERSION';
-$VERSION = '1.39';
+package Dancer2::Plugin::LogReport;{
+our $VERSION = '1.40';
+}
 
 
 use warnings;
@@ -74,7 +74,6 @@ on_plugin_import
         ),
     );
 
-
     if($settings->{handle_http_errors})
     {   # Need after_error for HTTP errors (eg 404) so as to
         # be able to change the forwarding location
