@@ -1,10 +1,10 @@
-# Copyrights 2007-2024 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2025 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.03.
-package DieTests;
-use vars '$VERSION';
-$VERSION = '1.39';
+package DieTests;{
+our $VERSION = '1.40';
+}
 
 use warnings;
 use strict;
